==> coupon-facade-1.0.2-20190214.063347-12-sources.jar: com/bizvane/couponfacade/models/vo/CouponListByMemberCodeRequestVO.java <==
package com.bizvane.couponfacade.models.vo;

import java.io.Serializable;

public class CouponListByMemberCodeRequestVO implements Serializable {

  /**
   * 
   */
  private static final long serialVersionUID = 1L;


  @io.swagger.annotations.ApiModelProperty(value = "会员号", name = "memberCode", required = false,example = "")
  private String memberCode;

  @io.swagger.annotations.ApiModelProperty(value = "券使用状态", name = "couponStatus", required = false,example = "")
  private Byte couponStatus;

  @io.swagger.annotations.ApiModelProperty(value = "品牌号", name = "sysBrandId", required = false,example = "")
  private Long sysBrandId;

  @io.swagger.annotations.ApiModelProperty(value = "显示条数", name = "pageSize")
  private Integer pageSize = 20;

  @io.swagger.annotations.ApiModelProperty(value = "当前页数", name = "page")
  private Integer pageNumber = 1;

  public Long getSysBrandId() {
    return sysBrandId;
  }

  public void setSysBrandId(Long sysBrandId) {
    this.sysBrandId = sysBrandId;
  }

  public String getMemberCode() {
    return memberCode;
  }

  public void setMemberCode(String memberCode) {
    this.memberCode = memberCode;
  }

  public Byte getCouponStatus() {
    return couponStatus;
  }

  public void setCouponStatus(Byte couponStatus) {
    this.couponStatus = couponStatus;
  }

  public Integer getPageSize() {
    return pageSize;
  }

  public void setPageSize(Integer pageSize) {
    this.pageSize = pageSize;
  }

  public Integer getPageNumber() {
    return pageNumber;
  }

  public void setPageNumber(Integer pageNumber) {
    this.pageNumber = pageNumber;
  }
}

==> coupon-facade-2.0.0-20200703.031717-147-sources.jar: com/bizvane/couponfacade/models/vo/CouponListByMemberCodeRequestVO.java <==
package com.bizvane.couponfacade.models.vo;

import java.io.Serializable;

public class CouponListByMemberCodeRequestVO implements Serializable {

  /**
   * 
   */
  private static final long serialVersionUID = 1L;

  @io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false,example = "")
  private Long sysBrandId;

  @io.swagger.annotations.ApiModelProperty(value = "公司id", name = "sysCompanyId", required = false,example = "")
  private Long sysCompanyId;

  @io.swagger.annotations.ApiModelProperty(value = "会员号", name = "memberCode", required = false,example = "")
  private String memberCode;

  @io.swagger.annotations.ApiModelProperty(value = "券使用状态", name = "couponStatus", required = false,example = "")
  private Byte couponStatus;

  @io.swagger.annotations.ApiModelProperty(value = "显示条数", name = "pageSize")
  private Integer pageSize = 20;

  @io.swagger.annotations.ApiModelProperty(value = "当前页数", name = "page")
  private Integer pageNumber = 1;

  public Long getSysCompanyId() {
    return sysCompanyId;
  }

  public void setSysCompanyId(Long sysCompanyId) {
    this.sysCompanyId = sysCompanyId;
  }

  public Long getSysBrandId() {
    return sysBrandId;
  }

  public void setSysBrandId(Long sysBrandId) {
    this.sysBrandId = sysBrandId;
  }

  public String getMemberCode() {
    return memberCode;
  }

  public void setMemberCode(String memberCode) {
    this.memberCode = memberCode;
  }

  public Byte getCouponStatus() {
    return couponStatus;
  }

  public void setCouponStatus(Byte couponStatus) {
    this.couponStatus = couponStatus;
  }

  public Integer getPageSize() {
    return pageSize;
  }

  public void setPageSize(Integer pageSize) {
    this.pageSize = pageSize;
  }

  public Integer getPageNumber() {
    return pageNumber;
  }

  public void setPageNumber(Integer pageNumber) {
    this.pageNumber = pageNumber;
  }
}
